@@ -51,11 +51,6 @@ class Builder(_BaseRepositoryObject):
     def __ne__(self, other):
         return not self == other
 
-    def sync(self):
-        """Synchronize local and remote repositories.
-        """
-        self.repo.sync()
-
     def run(self):
         """Perform one build iteration.
         """
@@ -105,7 +100,8 @@ class Builder(_BaseRepositoryObject):
                             if request.status in self.config.ends:
                                 break
 
-                    except ValueError:
+                    except ValueError as error:
+                        logging.warning(error)
                         logging.critical("deleting build request due to invalid configuration: {0}".format(request))
                         request.delete()
 
@@ -193,7 +189,6 @@ def run(config, daemon=False, test=False):
 
     while True:
         for builder in builders:
-            builder.sync()
             if isinstance(test, basestring):
                 logging.info("testing [{s}] of {b}...".format(b=builder, s=test))
                 builder.test(single=test)
@@ -203,7 +198,6 @@ def run(config, daemon=False, test=False):
             else:
                 logging.log(logging.DEBUG if daemon else logging.INFO, "running {b}...".format(b=builder))
                 builder.run()
-            builder.sync()
         if not daemon or test:
             break
 
@@ -222,6 +216,7 @@ def main():  # pragma: no cover - tested manually
     parser.add_argument('-t', '--test', metavar='ALIAS', nargs='?', const=True, help="dry run locally as a test")
     parser.add_argument('repo', nargs='*', help="repository names")
     parser.add_argument('--config', metavar='PATH', help="path to a configuration file")
+    parser.add_argument('--no-config', action='store_true', help="ignore local configuration files")
     parser.add_argument('--env', metavar='ALIAS', help="environment alias for this machine")
 
     # Parse arguments
@@ -231,7 +226,8 @@ def main():  # pragma: no cover - tested manually
     common.configure_logging(args.verbose)
 
     # Parse the configuration file
-    config = common.parse_config(args.config, parser.error, repos=args.repo, envs=[args.env] if args.env else None)
+    config = common.parse_config(args.config, not args.no_config, parser.error,
+                                 repos=args.repo, envs=[args.env] if args.env else None)
     if not config.repos:
         parser.error("specify at least one repository")
     if len(config.environments) != 1 and not args.test:
