@@ -243,14 +243,6 @@ class Repository(_Base):
             else:
                 self._push_time = time.time()
 
-    def sync(self):
-        """If enabled, perform an automatic pull and push.
-        """
-        if self._auto_pull:
-            self.pull(_auto=True)
-        if self._auto_push:
-            self.push(_auto=True)
-
     @property
     @auto_pull
     def branches(self):
@@ -371,7 +363,7 @@ class Repository(_Base):
         """
         user = User(name, repo=self)
         logging.info("setting '{u}' as the current user in repo '{r}'...".format(u=user, r=user.repo))
-        vv.run('whoami', user, repo=user.repo)
+        vv.run('whoami', '--create', user, repo=user.repo)
         return user
 
     @auto_pull
@@ -597,6 +589,7 @@ class Repository(_Base):
             args = name, series, environment, status, cid
         bid, cid, _name, _series, _environment = next(vscript.parse(vscript.report_build(self, 'new', *args),
                                                                     style='builds'))
+        self.push()  # new build requests should always be pushed
         return BuildRequest(bid, cid, name=name, series=series, environment=environment,
                             status=status, branch=branch, repo=self)
 
@@ -609,7 +602,7 @@ class Repository(_Base):
         @return: pending BuildRequest
         """
         logging.debug("getting the next build request for [{e}] in '{r}'...".format(e=environment, r=self))
-        args = self, 'get-pending-build', environment, order or BuildRequest.OLDEST, status
+        args = self, 'get-pending-build', environment, order or BuildRequest.NEWEST, status
         try:
             bid, cid, name, series, environment = next(vscript.parse(vscript.report_build(*args), style='builds'))
         except StopIteration:
@@ -625,6 +618,7 @@ class Repository(_Base):
         """
         logging.info("updating build '{b}' to status '{s}' in '{r}'...".format(b=bid, s=status, r=self))
         vscript.report_build(self, 'update', bid, status)
+        self.push()  # updated build statuses should always be pushed
 
     @auto_push
     def delete_build(self, bid):
@@ -756,6 +750,14 @@ class WorkingCopy(_BaseRepositoryObject):
         else:
             raise AttributeError
 
+    def copy(self, path):
+        """Create a copy of the working copy.
+        @param path: location of new working copy
+        @return: new WorkingCopy
+        """
+        shutil.copytree(self.path, path)
+        return WorkingCopy(path, repo=self.repo)
+
     @property
     @in_path
     def branch(self):
