@@ -28,6 +28,7 @@ def setUpModule():  # pylint: disable=C0103
     global TEMP_REPO  # pylint: disable=W0601
     if TEST_REPO:
         TEMP_REPO = TEST_REPO.clone(TEST_REPO.name + '-' + str(randrange(999)), autosync=False)
+        TEMP_REPO.user = 'testuser'
     else:
         TEMP_REPO = None
 
@@ -89,9 +90,10 @@ class TestRepository(unittest.TestCase):
         """Verify attribute access behaves normally for repositories."""
         self.assertRaises(AttributeError, getattr, TEST_REPO, '_invalid')
 
-    def test_sync(self):
+    def test_pull_push_with_no_remote(self):
         """Verify a non-cloned repository can handle pull/push."""
-        TEST_REPO.sync()
+        TEST_REPO.pull()
+        TEST_REPO.push()
 
 
 @unittest.skipUnless(TEST_REPO, REASON)  # pylint: disable=R0904
@@ -163,6 +165,15 @@ class TestWorkingCopy(unittest.TestCase):
             wc.chdir('temp')
             self.assertTrue(wc.status())
 
+    def test_copy(self):
+        """Verify a working copy can be copied."""
+        with TEST_REPO.checkout(tempfile.mkdtemp()) as wc:
+            log(wc)
+            with wc.copy(wc.path + '-copy') as wc2:
+                self.assertNotEqual(wc, wc2)
+                self.assertEqual(wc.repo, wc2.repo)
+                self.assertTrue(os.path.isdir(wc2.path))
+
 
 @unittest.skipUnless(TEST_REPO, REASON)  # pylint: disable=R0904
 class TestChangeset(unittest.TestCase):
