@@ -19,7 +19,7 @@ class TestCommands(unittest.TestCase):  # pylint: disable=R0904
         """Verify an exception is raised when initializing builds with missing arguments."""
         self.assertRaises(vscript.VeracityScriptException, vscript.init_builds, '')
 
-    def test_report_build_invalid(self):
+    def test_report_build_missing_args(self):
         """Verify an exception is raised when reporting builds with missing arguments."""
         self.assertRaises(vscript.VeracityScriptException, vscript.report_build, '')
 
