@@ -58,6 +58,9 @@ def run(*args, **kwargs):
     except ErrorReturnCode as erc:
         msg = "\n\nIN: {0}\n\nRAN: {1}\n\nOUTPUT:{2}\n".format(os.getcwd(), erc.full_cmd, erc.stderr.strip())
         raise VeracityException(msg)
+    except UnicodeDecodeError as ude:  # pragma: no cover - this occurs rarely
+        logging.warning(ude)
+        raise VeracityException("UnicodeDecodeError: {0}".format(ude))
     else:
         return result.stdout.strip()
 
